from distutils.core import setup
setup(
    name = "Happy_day",
    version = "1.0",
    description = "这是一个无用的测试模块",
    author= "liyi",
    author_email = "2307758843@qq.com",
    py_modules=["Happy_day.demo1","Happy_day.demo2"]
)